Models — django-guardian v1.0.0.beta1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- API Reference »

# Models

## BaseObjectPermission

class `guardian.models.` `BaseObjectPermission`(*args, **kwargs)

  Abstract ObjectPermission class.

  `content_object`

    Provides a generic relation to any object through content-type/object-id fields.

## UserObjectPermission

class `guardian.models.` `UserObjectPermission`(*args, **kwargs)

  Manager: `UserObjectPermissionManager`

  `content_object`

    Provides a generic relation to any object through content-type/object-id fields.

## GroupObjectPermission

class `guardian.models.` `GroupObjectPermission`(*args, **kwargs)

  Manager: `GroupObjectPermissionManager`

  `content_object`

    Provides a generic relation to any object through content-type/object-id fields.

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »
- API Reference »